"use strict";var t=function(s,r){return function(){return r||s((r={exports:{}}).exports,r),r.exports}};var o=t(function(c,e){
var a=Boolean;e.exports=a
});var i=o();module.exports=i;
/** @license Apache-2.0 */
//# sourceMappingURL=index.js.map
